==> ejc-supbid-impl-3.0.1-20211125.113231-21-sources.jar: com/ejianc/business/supbid/winbid/bean/WinbidDetailEntity.java <==
package com.ejianc.business.supbid.winbid.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 中标明细实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_winbid_material__detail")
public class WinbidDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="scheme_id")
    private java.lang.Long schemeId; // 方案主键
    @TableField(value="source_material_id")
    private java.lang.String sourceMaterialId; // 材料ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 材料名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 材料编码
    @TableField(value="source_material_type_id")
    private java.lang.String sourceMaterialTypeId; // 材料分类ID
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 材料分类名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="brand")
    private java.lang.String brand; // 品牌
    @TableField(value="calculate_type")
    private java.lang.Integer calculateType; // 计量方式(0-理计,1-过磅,2-点数)
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="rate")
    private java.math.BigDecimal rate; // 税率
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="supplier_brand")
    private java.lang.String supplierBrand; // 供货品牌
    @TableField(value="price")
    private java.math.BigDecimal price; // 单价
    @TableField(value="price_tax")
    private java.math.BigDecimal priceTax; // 单价(含税)
    @TableField(value="money")
    private java.math.BigDecimal money; // 总额
    @TableField(value="money_tax")
    private java.math.BigDecimal moneyTax; // 总额(含税)
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税额
    @TableField(value="supplier_memo")
    private java.lang.String supplierMemo; // 备注
    @TableField(value="winbid_id")
    private java.lang.Long winbidId; // 中标主键
    
    
    

    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案主键
     */
    public java.lang.Long getSchemeId() {
        return schemeId;
    }

    /**
     * 方案主键
     */
    public void setSchemeId(java.lang.Long schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 材料ID
     */
    public java.lang.String getSourceMaterialId() {
        return sourceMaterialId;
    }

    /**
     * 材料ID
     */
    public void setSourceMaterialId(java.lang.String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public java.lang.String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setSourceMaterialTypeId(java.lang.String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    /**
     * 材料分类名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public java.lang.Integer getCalculateType() {
        return calculateType;
    }

    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public void setCalculateType(java.lang.Integer calculateType) {
        this.calculateType = calculateType;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getRate() {
        return rate;
    }

    /**
     * 税率
     */
    public void setRate(java.math.BigDecimal rate) {
        this.rate = rate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 供货品牌
     */
    public java.lang.String getSupplierBrand() {
        return supplierBrand;
    }

    /**
     * 供货品牌
     */
    public void setSupplierBrand(java.lang.String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税)
     */
    public java.math.BigDecimal getPriceTax() {
        return priceTax;
    }

    /**
     * 单价(含税)
     */
    public void setPriceTax(java.math.BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    /**
     * 总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public java.lang.String getSupplierMemo() {
        return supplierMemo;
    }

    /**
     * 备注
     */
    public void setSupplierMemo(java.lang.String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    /**
     * 中标主键
     */
    public java.lang.Long getWinbidId() {
        return winbidId;
    }

    /**
     * 中标主键
     */
    public void setWinbidId(java.lang.Long winbidId) {
        this.winbidId = winbidId;
    }
    
}

==> ejc-supbid-impl-3.0.1-20231122.012641-251-sources.jar: com/ejianc/business/supbid/winbid/bean/WinbidDetailEntity.java <==
package com.ejianc.business.supbid.winbid.bean;

import java.math.BigDecimal;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 中标明细实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_supbid_winbid_material_detail")
public class WinbidDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="source_id")
    private java.lang.String sourceId; // 招标信息主键
    @TableField(value="scheme_id")
    private java.lang.Long schemeId; // 方案主键
    @TableField(value="source_material_id")
    private java.lang.String sourceMaterialId; // 材料ID
    @TableField(value="material_name")
    private java.lang.String materialName; // 材料名称
    @TableField(value="material_code")
    private java.lang.String materialCode; // 材料编码
    @TableField(value="source_material_type_id")
    private java.lang.String sourceMaterialTypeId; // 材料分类ID
    @TableField(value="material_type_name")
    private java.lang.String materialTypeName; // 材料分类名称
    @TableField(value="unit")
    private java.lang.String unit; // 单位
    @TableField(value="spec")
    private java.lang.String spec; // 规格型号
    @TableField(value="brand")
    private java.lang.String brand; // 品牌
    @TableField(value="calculate_type")
    private java.lang.Integer calculateType; // 计量方式(0-理计,1-过磅,2-点数)
    @TableField(value="num")
    private java.math.BigDecimal num; // 数量
    @TableField(value="tender_num")
    private java.math.BigDecimal tenderNum; // 中标数量
    @TableField(value="rate")
    private java.math.BigDecimal rate; // 税率
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="supplier_brand")
    private java.lang.String supplierBrand; // 供货品牌
    @TableField(value="price")
    private java.math.BigDecimal price; // 单价
    @TableField(value="price_tax")
    private java.math.BigDecimal priceTax; // 单价(含税)
    @TableField(value="money")
    private java.math.BigDecimal money; // 总额
    @TableField(value="money_tax")
    private java.math.BigDecimal moneyTax; // 总额(含税)
    @TableField(value="tax")
    private java.math.BigDecimal tax; // 税额
    @TableField(value="supplier_memo")
    private java.lang.String supplierMemo; // 备注
    @TableField(value="winbid_id")
    private java.lang.Long winbidId; // 中标主键


    public BigDecimal getTenderNum() {
        return tenderNum;
    }

    public void setTenderNum(BigDecimal tenderNum) {
        this.tenderNum = tenderNum;
    }

    /**
     * 招标信息主键
     */
    public java.lang.String getSourceId() {
        return sourceId;
    }

    /**
     * 招标信息主键
     */
    public void setSourceId(java.lang.String sourceId) {
        this.sourceId = sourceId;
    }
    /**
     * 方案主键
     */
    public java.lang.Long getSchemeId() {
        return schemeId;
    }

    /**
     * 方案主键
     */
    public void setSchemeId(java.lang.Long schemeId) {
        this.schemeId = schemeId;
    }
    /**
     * 材料ID
     */
    public java.lang.String getSourceMaterialId() {
        return sourceMaterialId;
    }

    /**
     * 材料ID
     */
    public void setSourceMaterialId(java.lang.String sourceMaterialId) {
        this.sourceMaterialId = sourceMaterialId;
    }
    /**
     * 材料名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 材料名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 材料编码
     */
    public java.lang.String getMaterialCode() {
        return materialCode;
    }

    /**
     * 材料编码
     */
    public void setMaterialCode(java.lang.String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 材料分类ID
     */
    public java.lang.String getSourceMaterialTypeId() {
        return sourceMaterialTypeId;
    }

    /**
     * 材料分类ID
     */
    public void setSourceMaterialTypeId(java.lang.String sourceMaterialTypeId) {
        this.sourceMaterialTypeId = sourceMaterialTypeId;
    }
    /**
     * 材料分类名称
     */
    public java.lang.String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 材料分类名称
     */
    public void setMaterialTypeName(java.lang.String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 单位
     */
    public java.lang.String getUnit() {
        return unit;
    }

    /**
     * 单位
     */
    public void setUnit(java.lang.String unit) {
        this.unit = unit;
    }
    /**
     * 规格型号
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 品牌
     */
    public java.lang.String getBrand() {
        return brand;
    }

    /**
     * 品牌
     */
    public void setBrand(java.lang.String brand) {
        this.brand = brand;
    }
    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public java.lang.Integer getCalculateType() {
        return calculateType;
    }

    /**
     * 计量方式(0-理计,1-过磅,2-点数)
     */
    public void setCalculateType(java.lang.Integer calculateType) {
        this.calculateType = calculateType;
    }
    /**
     * 数量
     */
    public java.math.BigDecimal getNum() {
        return num;
    }

    /**
     * 数量
     */
    public void setNum(java.math.BigDecimal num) {
        this.num = num;
    }
    /**
     * 税率
     */
    public java.math.BigDecimal getRate() {
        return rate;
    }

    /**
     * 税率
     */
    public void setRate(java.math.BigDecimal rate) {
        this.rate = rate;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 供货品牌
     */
    public java.lang.String getSupplierBrand() {
        return supplierBrand;
    }

    /**
     * 供货品牌
     */
    public void setSupplierBrand(java.lang.String supplierBrand) {
        this.supplierBrand = supplierBrand;
    }
    /**
     * 单价
     */
    public java.math.BigDecimal getPrice() {
        return price;
    }

    /**
     * 单价
     */
    public void setPrice(java.math.BigDecimal price) {
        this.price = price;
    }
    /**
     * 单价(含税)
     */
    public java.math.BigDecimal getPriceTax() {
        return priceTax;
    }

    /**
     * 单价(含税)
     */
    public void setPriceTax(java.math.BigDecimal priceTax) {
        this.priceTax = priceTax;
    }
    /**
     * 总额
     */
    public java.math.BigDecimal getMoney() {
        return money;
    }

    /**
     * 总额
     */
    public void setMoney(java.math.BigDecimal money) {
        this.money = money;
    }
    /**
     * 总额(含税)
     */
    public java.math.BigDecimal getMoneyTax() {
        return moneyTax;
    }

    /**
     * 总额(含税)
     */
    public void setMoneyTax(java.math.BigDecimal moneyTax) {
        this.moneyTax = moneyTax;
    }
    /**
     * 税额
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税额
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 备注
     */
    public java.lang.String getSupplierMemo() {
        return supplierMemo;
    }

    /**
     * 备注
     */
    public void setSupplierMemo(java.lang.String supplierMemo) {
        this.supplierMemo = supplierMemo;
    }
    /**
     * 中标主键
     */
    public java.lang.Long getWinbidId() {
        return winbidId;
    }

    /**
     * 中标主键
     */
    public void setWinbidId(java.lang.Long winbidId) {
        this.winbidId = winbidId;
    }
    
}
